@@ -68,9 +68,9 @@ newcgd <- tmerge(newcgd, cgd0, id=id, infect = event(etime7))
 newcgd <- tmerge(newcgd, newcgd, id, enum=cumtdc(tstart))
 dim(newcgd)
 newcgd[1:5,c(1, 4:6, 13:17)]
-attr(newcgd, "tcount")
-coxph(Surv(tstart, tstop, infect) ~ treat + inherit + steroids +
-      + cluster(id), newcgd)
+summary(newcgd)
+coxph(Surv(tstart, tstop, infect) ~ treat + inherit + steroids,
+      data =newcgd, cluster = id)
 
 
 ###################################################
@@ -129,20 +129,20 @@ rbind('baseline fit' = coef(fit1),
 
 
 ###################################################
-### code chunk number 11: timedep.Rnw:592-593
+### code chunk number 11: timedep.Rnw:598-599
 ###################################################
 attr(pbc2, "tcount")
 
 
 ###################################################
-### code chunk number 12: timedep.Rnw:595-597
+### code chunk number 12: timedep.Rnw:601-603
 ###################################################
 #grab a couple of numbers for the paragraph below
 atemp <- attr(pbc2, "tcount")[2:3,]
 
 
 ###################################################
-### code chunk number 13: timedep.Rnw:678-684 (eval = FALSE)
+### code chunk number 13: timedep.Rnw:684-690 (eval = FALSE)
 ###################################################
 ## temp <- subset(pbc, id <= 312, select=c(id:sex, stage))
 ## pbc2 <- tmerge(temp, temp, id=id, death = event(time, status))
@@ -167,21 +167,26 @@ atemp <- attr(pbc2, "tcount")[2:3,]
 ###################################################
 ### code chunk number 15: veteran1
 ###################################################
-getOption("SweaveHooks")[["fig"]]()
-options(show.signif.stars = FALSE)  # display user intelligence
+options(show.signif.stars = FALSE)  # display statistical intelligence
 vfit <- coxph(Surv(time, status) ~ trt + prior + karno, veteran)
 vfit
 quantile(veteran$karno)
 
 zp <- cox.zph(vfit, transform= function(time) log(time +20))
 zp
-plot(zp[3])    # a plot for the 3rd variable in the fit
-abline(0,0, col=2)
-abline(h= vfit$coef[3], col=3, lwd=2, lty=2)
 
 
 ###################################################
-### code chunk number 16: split
+### code chunk number 16: veteran1b
+###################################################
+getOption("SweaveHooks")[["fig"]]()
+plot(zp[3], resid=FALSE)    # a plot for the 3rd variable in the fit
+abline(0,0, lty=3)
+abline(h= vfit$coef[3], lwd=2, lty=3)
+
+
+###################################################
+### code chunk number 17: split
 ###################################################
 vet2 <- survSplit(Surv(time, status) ~ ., data= veteran, cut=c(90, 180), 
                   episode= "tgroup", id="id")
@@ -189,7 +194,7 @@ vet2[1:7, c("id", "tstart", "time", "status", "tgroup", "age", "karno")]
 
 
 ###################################################
-### code chunk number 17: split2
+### code chunk number 18: split2
 ###################################################
 vfit2 <- coxph(Surv(tstart, time, status) ~ trt + prior +
                   karno:strata(tgroup), data=vet2)
@@ -198,14 +203,15 @@ cox.zph(vfit2)
 
 
 ###################################################
-### code chunk number 18: split3
+### code chunk number 19: split3
 ###################################################
 vfit2$means
 
 
 ###################################################
-### code chunk number 19: split4
+### code chunk number 20: split4
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 quantile(veteran$karno)
 cdata <- data.frame(tstart= rep(c(0,90,180), 2),
                     time =  rep(c(90,180, 365), 2),
@@ -224,14 +230,14 @@ lines(sfit, col=1:2, lty=2, lwd=2)
 
 
 ###################################################
-### code chunk number 20: vfit3 (eval = FALSE)
+### code chunk number 21: vfit3 (eval = FALSE)
 ###################################################
 ## vfit3 <- coxph(Surv(time, status) ~ trt + prior + karno +
 ##                 I(karno * log(time + 20)), data=veteran)
 
 
 ###################################################
-### code chunk number 21: vet3
+### code chunk number 22: vet3
 ###################################################
 vfit3 <-  coxph(Surv(time, status) ~ trt + prior + karno + tt(karno),
                 data=veteran,
@@ -240,15 +246,25 @@ vfit3
 
 
 ###################################################
-### code chunk number 22: vet3b
+### code chunk number 23: vet3b
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(zp[3])
-abline(coef(vfit3)[3:4], col=2)
+abline(coef(vfit3)[3:4], lwd=2, lty=3, col=2)
 
 
 ###################################################
-### code chunk number 23: ties1
+### code chunk number 24: vet4
+###################################################
+vfit4 <-  coxph(Surv(time, status) ~ trt + prior + karno + tt(karno),
+                data=veteran,
+                tt = function(x, t, ...) x* nsk(t, knots=c(5, 100, 200, 400),
+                                                Boundary = FALSE))
+vfit4
+
+
+###################################################
+### code chunk number 25: ties1
 ###################################################
 data1 <- read.table(col.names=c("id", "diabetes", "lfu", "status"),
                           header=FALSE, text="
@@ -270,7 +286,7 @@ c(coef(fit1), coef(fit2))
 
 
 ###################################################
-### code chunk number 24: ties2
+### code chunk number 26: ties2
 ###################################################
 data2 <- tmerge(data1, data1, id=id, dstat=event(lfu, status),
                 diab = tdc(diabetes))
@@ -280,14 +296,14 @@ c(coef(fit1), coef(fit2), coef(fit3))
 
 
 ###################################################
-### code chunk number 25: pbctime
+### code chunk number 27: pbctime
 ###################################################
 pfit1 <- coxph(Surv(time, status==2) ~ log(bili) + ascites + age, pbc)
 pfit2 <- coxph(Surv(time, status==2) ~ log(bili) + ascites + tt(age),
                 data=pbc,
                 tt=function(x, t, ...) {
                     age <- x + t/365.25 
-                    cbind(age=age, age2= (age-50)^2, age3= (age-50)^3)
+                    cbind(cage=age, cage2= (age-50)^2, cage3= (age-50)^3)
                 })
 pfit2
 anova(pfit2)
@@ -296,7 +312,7 @@ anova(pfit2)
 
 
 ###################################################
-### code chunk number 26: expand
+### code chunk number 28: expand
 ###################################################
 dtimes <- sort(unique(with(pbc, time[status==2])))
 tdata <- survSplit(Surv(time, status==2) ~., pbc, cut=dtimes)
@@ -307,7 +323,7 @@ rbind(coef(pfit2), coef(pfit3))
 
 
 ###################################################
-### code chunk number 27: expand2
+### code chunk number 29: expand2
 ###################################################
 dtime2 <- 1:11 * 365.25
 tdata2 <-survSplit(Surv(time, status==2) ~., pbc, cut=dtime2)
@@ -320,7 +336,26 @@ c(tdata=nrow(tdata), tdata2=nrow(tdata2))
 
 
 ###################################################
-### code chunk number 28: timedep.Rnw:1185-1192
+### code chunk number 30: veteran3
+###################################################
+getOption("SweaveHooks")[["fig"]]()
+dtime <- round(1:13 * 30.5)
+vdata2 <- survSplit(Surv(time, status) ~ ., veteran, cut=dtime,
+                    episode= "month")
+vfit1 <- coxph(Surv(tstart, time, status) ~ trt + prior + karno, vdata2)
+vfit5 <- coxph(Surv(tstart, time, status) ~ trt + prior + karno + 
+                   karno:nsk(month, df=3), vdata2)
+anova(vfit1, vfit5)
+
+tdata <- expand.grid(trt=0, prior=0, karno=30, month=seq(1,13, length=50))
+yhat <- predict(vfit5, newdata=tdata, se.fit=TRUE, reference="zero")
+yy <- yhat$fit+ outer(yhat$se.fit, c(0, -1.96, 1.96), '*')
+matplot(seq(1,13, length=50), yy, type='l', lty=c(1,2,2), col=1, lwd=c(1,2,2),
+        xlab="Month of fu", ylab="Effect, Karnofsky 60 vs 90")
+
+
+###################################################
+### code chunk number 31: timedep.Rnw:1268-1275
 ###################################################
 function(x, t, riskset, weights){ 
     obrien <- function(x) {
@@ -332,7 +367,7 @@ function(x, t, riskset, weights){
 
 
 ###################################################
-### code chunk number 29: timedep.Rnw:1202-1204
+### code chunk number 32: timedep.Rnw:1285-1287
 ###################################################
 function(x, t, riskset, weights) 
     unlist(tapply(x, riskset, rank))
