@@ -80,7 +80,7 @@
 static double **covar, **cmat, **cmat2;
 static double *a, *oldbeta, *a2;
 static double *offset, *weights;
-static int    *event, *frail;
+static int    *event, *frail = NULL;
 static double *score, *start, *stop;
 static int    *sort1, *sort2;
 static double *tmean;
@@ -98,7 +98,8 @@ void agfit5a(Sint *nusedx, Sint *nvarx, double *yy,
 	       double *loglik, 
 	       Sint *methodx, Sint *ptype2, Sint *pdiag2,
 	       Sint *nfrail,  Sint *frail2,
-               void *fexpr1, void *fexpr2, void *rho) {
+               void *fexpr1, void *fexpr2, void *rho,
+	       Sint *docenter) {
 
     int i,j,k, person;
     int     nused, nvar;
@@ -131,7 +132,7 @@ void agfit5a(Sint *nusedx, Sint *nvarx, double *yy,
 	cmat2= cmatrix(0, nvar2, nvar+1);
         }
 
-    a = Calloc(4*nvar2 + 5*nused , double);
+    a = CALLOC(4*nvar2 + 5*nused , double);
     oldbeta = a + nvar2;
     a2 =  oldbeta + nvar2;
     weights = a2+ nvar2;
@@ -141,7 +142,7 @@ void agfit5a(Sint *nusedx, Sint *nvarx, double *yy,
     start   = tmean + nvar2;
     stop    = start + nused;
     
-    event  = Calloc(3*nused, int);
+    event  = CALLOC(3*nused, int);
     sort1   = event + nused;
     sort2   = sort1 + nused;
 
@@ -161,28 +162,31 @@ void agfit5a(Sint *nusedx, Sint *nvarx, double *yy,
     */
     if (nf > nvar) i=nf; else i=nvar;
     if (nf > nvar*nvar) j=nf; else j=nvar*nvar;
-    if (pdiag==0)  upen = Calloc(2*i, double);
-    else           upen = Calloc(i+j, double);
+    if (pdiag==0)  upen = CALLOC(2*i, double);
+    else           upen = CALLOC(i+j, double);
     ipen = upen + i;
-    if (ptype>1)  zflag = Calloc(nvar, Sint);
-    else          zflag = Calloc(2, Sint);
+    if (ptype>1)  zflag = CALLOC(nvar, Sint);
+    else          zflag = CALLOC(2, Sint);
 
     if (nf>0) {
-	frail = Calloc(nused, int);
+	frail = CALLOC(nused, int);
 	for (i=0; i<nused; i++) frail[i] = frail2[i];
         }
 
     /*
     ** Subtract the mean from each covar, as this makes the regression
-    **  much more stable
+    **  more stable
     */
     for (i=0; i<nvar; i++) {
-	temp=0;
-	for (person=0; person<nused; person++) temp += covar[i][person];
-	temp /= nused;
-	means[i] = temp;
-	for (person=0; person<nused; person++) covar[i][person] -=temp;
+	if (docenter[i] ==0) means[i] =0;
+	else {
+	    temp=0;
+	    for (person=0; person<nused; person++) temp += covar[i][person];
+	    temp /= nused;
+	    means[i] = temp;
+	    for (person=0; person<nused; person++) covar[i][person] -=temp;
 	}
+    }	
 	
     /*
     ** Find the loglik of the initial model
@@ -577,7 +581,8 @@ void agfit5b(Sint *maxiter, Sint *nusedx, Sint *nvarx,
 	**   update the betas and test for convergence
 	*/
 	*flag = cholesky3(jmat, nvar2, nf, fdiag, *tolerch);
-	if (fabs(1-(*loglik/newlk))<=*eps && halving==0) { /* all done */
+	if (fabs(newlk) < *eps ||
+	    (fabs(1-(*loglik/newlk))<=*eps && halving==0)) { /* all done */
 	    *loglik = newlk;
 	    for (i=0; i<nvar; i++) {
 		for (j=0; j<nvar2; j++)  imat[i][j] = jmat[i][j];
@@ -648,8 +653,8 @@ static double **cmatrix(double *data, int ncol, int nrow)
     double **pointer;
     double *temp;
  
-    pointer = Calloc(nrow, double *);
-    temp =    Calloc(nrow*ncol, double);
+    pointer = CALLOC(nrow, double *);
+    temp =    CALLOC(nrow*ncol, double);
     if (data==0){
 	for (i=0; i<nrow; i++) {
 	    pointer[i] = temp;
@@ -666,18 +671,19 @@ static double **cmatrix(double *data, int ncol, int nrow)
 	}
 
 static void cmatrix_free(double **data) {
-    Free(*data);
-    Free(data);
+    FREE(*data);
+    FREE(data);
     }
 
 void agfit5c(Sint *nvar) {
     /*
-    ** Free up the extra memory
+    ** FREE up the extra memory
     */
-    Free(zflag);
-    Free(upen);
-    Free(event);
-    Free(a);
+    FREE(zflag);
+    FREE(upen);
+    FREE(event);
+    FREE(a);
+    if (frail != NULL) FREE(frail);
     if (*nvar > 0) {
 	cmatrix_free(cmat2);
 	cmatrix_free(cmat);
