@@ -14,4 +14,5 @@
 **  latter for objects that need to to persist between calls.
 */
 #define ALLOC(a,b)  R_alloc(a,b)
-
+#define CALLOC(a,b) R_Calloc(a,b)
+#define FREE(a)     R_Free(a)
